import Layout from "~src/layout/index.vue";

//路由菜单系统内置页面配置
export default [
    {
        path: '/',
        redirect: '/home/index'
    },
    {
        path: '/login',
        name: 'login',
        meta: {title: '登录'},
        component: () => import('~src/views/login/index.vue')
    },
    {
        path: '/home',
        name: 'home',
        redirect: '/home/index',
        meta: {title: '首页'},
        component: Layout,
        children: [
            {
                path: '/home/index',
                name: 'home-index',
                meta: {title: '首页'},
                component: () => import('~src/views/home/index.vue')
            },
            {
                path: '/home/config',
                name: 'home-config',
                meta: {title: '系统设置'},
                component: () => import('~src/views/home/config.vue')
            },
        ],
    },
    {
        path: '/data-fill',
        name: 'data-fill',
        redirect: '/data-fill/wbs',
        meta: {title: '资料管理'},
        component: Layout,
        children: [
            {
                path: '/data-fill/wbs',
                name: 'data-fill-wbs',
                meta: {title: '开工报告、质量评定 中间交工、工序资料'},
                component: () => import('~src/views/data-fill/wbs.vue')
            },
            {
                path: '/data-fill/query',
                name: 'data-query',
                meta: {title: '资料查询、下载、上报、验签、打印'},
                component: () => import('~src/views/data-fill/query.vue')
            }
        ],
    },
    {
        path: '/ledger',
        name: 'ledger',
        redirect: '/ledger/query',
        meta: {title: '台账日志'},
        component: Layout,
        children: [
            {
                path: '/ledger/query',
                name: 'ledger-write',
                meta: {title: '日志填报'},
                component: () => import('~src/views/ledger/query.vue')
            },
            {
                path: '/ledger/write',
                name: 'ledger-query',
                meta: {title: '台账管理'},
                component: () => import('~src/views/ledger/write.vue')
            }
        ],
    },
    {
        path: '/schedule',
        name: 'schedule',
        redirect: '/schedule/write',
        meta: {title: '进度查询'},
        component: Layout,
        children: [
            {
                path: '/schedule/write',
                name: 'schedule-internal',
                meta: {title: '内外业进度'},
                component: () => import('~src/views/schedule/write.vue')
            },
            {
                path: '/schedule/data',
                name: 'schedule-data',
                meta: {title: '资料进度'},
                component: () => import('~src/views/schedule/hc-data.vue')
            },
            {
                path: '/schedule/table',
                name: 'schedule-table',
                meta: {title: 'WBS节点进度'},
                component: () => import('~src/views/schedule/hc-table.vue')
            },
        ],
    },
    {
        path: '/other-file',
        name: 'other-file',
        redirect: '/other-file/image-data',
        meta: {title: '其他文件'},
        component: Layout,
        children: [
            {
                path: '/other-file/image-data',
                name: 'image-data',
                meta: {title: '影像资料'},
                component: () => import('~src/views/other-file/image-data.vue')
            },
            {
                path: '/other-file/image-view',
                name: 'other-file-view',
                meta: {title: '查看影像资料'},
                component: () => import('~src/views/other-file/image-view.vue')
            },
            {
                path: '/other-file/image-form',
                name: 'other-file-form',
                meta: {title: '影像资料上传'},
                component: () => import('~src/views/other-file/image-form.vue')
            },
            {
                path: '/other-file/project-scanning',
                name: 'project-scanning',
                meta: {title: '工程文件扫描、上传'},
                component: () => import('~src/views/other-file/project-scanning.vue')
            }
        ],
    },
    {
        path: '/gauge',
        name: 'gauge-base',
        redirect: '/gauge/station',
        meta: {title: '综合管理'},
        component: Layout,
        children: [
            {
                path: '/gauge/station',
                name: 'gauge-station',
                meta: {title: '测站点'},
                component: () => import('~src/views/gauge/station.vue')
            },
            {
                path: '/gauge/bezier',
                name: 'gauge-bezier',
                meta: {title: '平曲线'},
                component: () => import('~src/views/gauge/bezier.vue')
            },
            {
                path: '/other/first-item',
                name: 'other-first-item',
                meta: {title: '首件工程'},
                component: () => import('~src/views/other/first-item.vue')
            }
        ],
    },
    {
        path: '/tasks',
        name: 'tasks',
        redirect: '/tasks/data',
        meta: {title: '任务管理'},
        component: Layout,
        children: [
            {
                path: '/tasks/hc-data',
                name: 'tasks-data',
                meta: {title: '待办任务、已办任务、任务查看'},
                component: () => import('~src/views/tasks/hc-data.vue')
            },
            {
                path: '/tasks/flow',
                name: 'tasks-flow',
                meta: {title: '任务流程设置'},
                component: () => import('~src/views/tasks/flow.vue')
            },
            {
                path: '/tasks/sign-admin',
                name: 'sign-admin',
                meta: {title: '电签管理员'},
                component: () => import('~src/views/tasks/sign-admin.vue')
            },
            {
                path: '/tasks/message-data',
                name: 'message-data',
                meta: {title: '消息提醒'},
                component: () => import('~src/views/tasks/message-data.vue')
            }
        ],
    },
    {
        path: '/other',
        name: 'other',
        redirect: '/other/order-service',
        meta: {title: '其他页面'},
        component: Layout,
        children: [
            {
                path: '/other/order-service',
                name: 'order-service',
                meta: {title: '工单服务'},
                component: () => import('~src/views/other/order-service.vue')
            },
            {
                path: '/user/index',
                name: 'user-index',
                meta: {title: '个人中心'},
                component: () => import('~src/views/user/index.vue')
            }
        ],
    },
    {
        path: '/403',
        name: '403',
        meta: {title: '403'},
        component: () => import('~src/views/error/403.vue')
    },
    {
        path: '/404',
        name: '404',
        meta: {title: '404'},
        component: () => import('~src/views/error/404.vue')
    },
    {
        path: '/500',
        name: '500',
        meta: {title: '500'},
        component: () => import('~src/views/error/500.vue')
    },
    {
        path: '/:path(.*)*',
        redirect: '/404'
    }
]
